@@ -12,9 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
-__author__ = 'Mike Babineau <mikeb@ea2d.com>'
+__author__ = 'Mike Babineau <michael.babineau@gmail.com>'
 __copyright__ = "Copyright 2011 Electronic Arts Inc."
 __license__ = "Apache v2.0"
 
